@@ -94,7 +94,7 @@ function (hourtemps,Start_JDay=1,End_JDay=366,models=list(Chilling_Hours=Chillin
       for(m in 1:length(models))
         hourtemps[,names(models)[m]]<-do.call(models[[m]], list(hourtemps[,"Temp"]), quote = FALSE, envir = parent.frame())
 
-      seasons<-unique(hourtemps$sea)
+      seasons<-as.numeric(unique(hourtemps$sea))
       seasons<-seasons[!is.na(seasons)]
 
 #summarize all models
@@ -117,7 +117,9 @@ for (sea in seasons)
       if("no_Tmin" %in% names(hourtemps)&"no_Tmax" %in% names(hourtemps))
         chillout[which(chillout$End_year==sea),"Interpolated_days"]<-length(which(seas$no_Tmin|seas$no_Tmax))/24
         chillout[,"Perc_complete"]<-NA
-      if(sea==seasons[1]) last_end<-hourtemps[1,]-hourtemps[1,] else last_end<-hourtemps[min(which(hourtemps$sea==sea))-1,]
+        if (sea == seasons[1]&(Start_JDay>End_JDay|Start_JDay==hourtemps$JDay[1]))
+          {temp<-seas[,names(models)]
+           last_end <- temp[1, ] - temp[1, ]} else last_end<-hourtemps[min(which(hourtemps$sea==sea))-1,]
         for(m in 1:length(models))
           chillout[which(chillout$End_year==sea),names(models)[m]]<-seas[nrow(seas),names(models)[m]]-last_end[,names(models)[m]]
 }
